@@ -25,7 +25,6 @@ from liminal.errors import AuthError, RequestError
 from liminal.helpers.typing import ValidatedResponseT
 
 DEFAULT_REQUEST_TIMEOUT: Final[int] = 60
-DEFAULT_SOURCE: Final[str] = "sdk"
 
 
 class Client:
@@ -36,22 +35,20 @@ class Client:
         auth_provider: AuthProvider,
         api_server_url: str,
         *,
-        source: str = DEFAULT_SOURCE,
         httpx_client: AsyncClient | None = None,
     ) -> None:
         """Initialize.
 
         Args:
+        ----
             auth_provider: The instantiated auth provider to use.
             api_server_url: The URL of the Liminal API server.
-            source: The source of the SDK.
             httpx_client: An optional HTTPX client to use.
 
         """
         self._api_server_url = api_server_url
         self._auth_provider = auth_provider
         self._httpx_client = httpx_client
-        self._source = source
 
         # Token information:
         self._access_token: str | None = None
@@ -79,6 +76,7 @@ class Client:
         """Make a request to the Liminal API server and return a Response.
 
         Args:
+        ----
             method: The HTTP method to use.
             endpoint: The endpoint to request.
             headers: The headers to use.
@@ -87,9 +85,11 @@ class Client:
             json: The JSON body to use.
 
         Returns:
+        -------
             An HTTPX Response object.
 
         Raises:
+        ------
             RequestError: If the response fails for any reason.
 
         """
@@ -107,10 +107,6 @@ class Client:
         if self._access_token:
             headers["Authorization"] = f"Bearer {self._access_token}"
 
-        if not params:
-            params = {}
-        params["source"] = self._source
-
         if running_client := self._httpx_client and not self._httpx_client.is_closed:
             client = self._httpx_client
         else:
@@ -150,6 +146,7 @@ class Client:
         """Make a request to the Liminal API server and validate the response.
 
         Args:
+        ----
             method: The HTTP method to use.
             endpoint: The endpoint to request.
             expected_response_type: The expected type of the response.
@@ -159,9 +156,11 @@ class Client:
             json: The JSON body to use.
 
         Returns:
+        -------
             A validated response object.
 
         Raises:
+        ------
             RequestError: If the response could not be validated.
 
         """
@@ -184,6 +183,7 @@ class Client:
         """Save tokens from an auth response.
 
         Args:
+        ----
             auth_response: The response from an auth request.
 
         """
@@ -206,9 +206,11 @@ class Client:
         persistent store using their own callback method.
 
         Args:
+        ----
             callback: The callback to add.
 
         Returns:
+        -------
             A method to cancel and remove the callback.
 
         """
@@ -236,10 +238,12 @@ class Client:
         """Authenticate with the Liminal API server (using a refresh token).
 
         Args:
+        ----
             refresh_token: The refresh token to use. If not provided, the refresh token
                 that was used to authenticate the user initially will be used.
 
         Raises:
+        ------
             AuthError: If no refresh token is provided and the user has not been
                 authenticated yet.
 
